@@ -1,39 +1,6 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is a Python binding for Network Security Services (NSS).
- *
- * The Initial Developer of the Original Code is Red Hat, Inc.
- *   (Author: John Dennis <jdennis@redhat.com>)
- *
- * Portions created by the Initial Developer are Copyright (C) 2008,2009
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above.  If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 // FIXME: some of these class types have items in them with arenas, but we can't hold a reference
 //        to an arena, so check to make sure we copy the items out and don't store the
@@ -86,6 +53,7 @@ typedef enum SECItemKindEnum {
     SECITEM_oid,
     SECITEM_utf8_string,
     SECITEM_bit_string,
+    SECITEM_certificate,
 } SECItemKind;
 
 typedef struct {
@@ -174,15 +142,22 @@ typedef struct {
     PyObject *py_public_value;
 } DSAPublicKey;
 
+/* ========================================================================== */
+/* ============================ RSAGenParams Class ========================== */
+/* ========================================================================== */
+
+typedef struct {
+    PyObject_HEAD
+    PK11RSAGenParams params;
+} RSAGenParams;
+
 /* ========================================================================== */
 /* ============================ KEYPQGParams Class ========================== */
 /* ========================================================================== */
 
 typedef struct {
     PyObject_HEAD
-    PyObject *py_prime;
-    PyObject *py_subprime;
-    PyObject *py_base;
+    SECKEYPQGParams params;
 } KEYPQGParams;
 
 /* ========================================================================== */
@@ -309,6 +284,25 @@ typedef struct {
     PyObject *py_pts;
 } CRLDistributionPts;
 
+/* ========================================================================== */
+/* ========================== AuthorityInfoAccess Class ===================== */
+/* ========================================================================== */
+
+typedef struct {
+    PyObject_HEAD
+    PRArenaPool *arena;
+    CERTAuthInfoAccess *aia;
+} AuthorityInfoAccess;
+
+/* ========================================================================== */
+/* ========================= AuthorityInfoAccesses Class ==================== */
+/* ========================================================================== */
+
+typedef struct {
+    PyObject_HEAD
+    PyObject *py_aias;
+} AuthorityInfoAccesses;
+
 /* ========================================================================== */
 /* ============================== AuthKeyID Class =========================== */
 /* ========================================================================== */
@@ -377,10 +371,29 @@ typedef struct {
 
 typedef struct {
     PyObject_HEAD
+    SECItem *ucs2_password_item;
     SEC_PKCS12DecoderContext *decoder_ctx;
     PyObject *py_decode_items;    /* tuple */
 } PKCS12Decoder;
 
+/* ========================================================================== */
+/* ========================== CertVerifyLogNode Class ======================= */
+/* ========================================================================== */
+
+typedef struct {
+    PyObject_HEAD
+    CERTVerifyLogNode node;
+} CertVerifyLogNode;
+
+/* ========================================================================== */
+/* ============================ CertVerifyLog Class ========================= */
+/* ========================================================================== */
+
+typedef struct {
+    PyObject_HEAD
+    CERTVerifyLog log;
+} CertVerifyLog;
+
 /* ========================================================================== */
 
 typedef struct {
@@ -389,9 +402,9 @@ typedef struct {
     PyTypeObject *certificate_type;
     PyTypeObject *private_key_type;
     PyTypeObject *sec_item_type;
-    PyObject *(*Certificate_new_from_CERTCertificate)(CERTCertificate *cert);
+    PyObject *(*Certificate_new_from_CERTCertificate)(CERTCertificate *cert, bool add_reference);
     PyObject *(*PrivateKey_new_from_SECKEYPrivateKey)(SECKEYPrivateKey *private_key);
-    PyObject *(*SecItem_new_from_SECItem)(SECItem *item, SECItemKind type);
+    PyObject *(*SecItem_new_from_SECItem)(const SECItem *item, SECItemKind type);
     PyObject *(*cert_distnames_new_from_CERTDistNames)(CERTDistNames *names);
     CERTDistNames *(*cert_distnames_as_CERTDistNames)(PyObject *py_distnames);
 } PyNSPR_NSS_C_API_Type;
